package com.yonyou.occ.codegenerator;

/**
 * 代码生成器帮助类。
 *
 * @author wangruiv
 * @date 2017-06-18 16:56:34
 */
public class GeneratorHelper {
	/**
	 * 通过数据库表名获取类名。
	 *
	 * @param tableCode 数据库表名。
	 * @return 类名。
	 */
	public static String getClassName(String tableCode) {
		String className = "";
		String[] parts = tableCode.split("_");
		for (int i = 1; i < parts.length; ++i) {
			String part = parts[i];
			part = part.substring(0, 1).toUpperCase() + part.substring(1).toLowerCase();
			className += part;
		}
		return className;
	}

	/**
	 * 通过数据库表名获取请求路径。
	 *
	 * @param tableCode 数据库表名。
	 * @return 类名。
	 */
	public static String getRequestMapping(String tableCode) {
		String className = "";
		String[] parts = tableCode.split("_");
		for (int i = 1; i < parts.length; ++i) {
			String part = parts[i];
			part = part.toLowerCase();
			className += "-" + part;
		}
		return parts[0].toLowerCase() + "/" + className.substring(1);
	}

	/**
	 * 通过数据库列名获取字段名。
	 *
	 * @param columnCode 数据库列名。
	 * @return 字段名。
	 */
	public static String getFieldName(String columnCode) {
		String fieldName = "";
		String[] parts = columnCode.split("_");
		for (int i = 0; i < parts.length; ++i) {
			String part = parts[i];
			if (i == 0) {
				part = part.toLowerCase();
			}
			else {
				part = part.substring(0, 1).toUpperCase() + part.substring(1).toLowerCase();
			}
			fieldName += part;
		}
		return fieldName;
	}

	/**
	 * 通过数据库列名获取属性名。
	 *
	 * @param columnCode 数据库列名。
	 * @return 字段名。
	 */
	public static String getPropertyName(String columnCode) {
		String className = "";
		String[] parts = columnCode.split("_");
		for (int i = 0; i < parts.length; ++i) {
			String part = parts[i];
			part = part.substring(0, 1).toUpperCase() + part.substring(1).toLowerCase();
			className += part;
		}
		return className;
	}

	public static String getFieldType(String typeInDb) {
		typeInDb = typeInDb.toUpperCase();

//		if (typeInDb.equals("NUMBER(1)")) {
//			return "Boolean";
//		}

		if (typeInDb.matches("NUMBER\\(\\s*\\d+\\s*\\)")) {
			return "Integer";
		}

		if (typeInDb.matches("NUMBER\\(\\s*\\d+\\s*,\\s*\\d+\\s*\\)")) {
			return "BigDecimal";
		}

		if (typeInDb.equals("DATE")) {
			return "Date";
		}

		return "String";
	}
}
